#!/bin/bash
#
# Copyright (C) 2023 MOXA Inc. All rights reserved.
# This software is distributed under the terms of the MOXA SOFTWARE NOTICE.
# See the file LICENSE for details.
#
# Authors:
#       2023  Wilson YS Huang  <wilsonys.huang@moxa.com>

source "${INSTL_SCRIPT_DIR}/lib/util.sh"
source "${INSTL_SCRIPT_DIR}/lib/logger.sh"
log::init "${INSTL_LOG_FILE}" "${INSTL_LOG_LEVEL}"

set -e

REPO_NAME="moxa-it87-serial-driver"
SRC_PATH_PREFIX="${INSTL_TOP_DIR}/src/${REPO_NAME}"

main() {
        local src_tag
        local src_ver
        src_tag="$1"
        src_ver="$2"

        log::info "Installing ${REPO_NAME} (${src_ver})"

        {
                pushd "${SRC_PATH_PREFIX}-${src_tag}" >/dev/null

                make clean
                make install
                make load

                popd
        } >>"${INSTL_LOG_FILE}" 2>&1

        log::info " Installing setserial tool"

        case "${LINUX_DISTRO_ID}" in
        "debian" | "ubuntu")
                {
                        apt-get update
                        apt-get install setserial -y
                } >>"${INSTL_LOG_FILE}" 2>&1

                ;;
        "rhel" | "centos")
                {
                        yum makecache
                        yum install setserial -y
                } >>"${INSTL_LOG_FILE}" 2>&1
                ;;
        esac
}

main "$@"
